angular.module("deliveryController", ["ionic", "services", "tools"]).controller("DeliveryCompanyCtrl", ["$scope", "$state", "psisServices", "lbScrollDelegate", "Tools", "lruPersistCache", "lbSpinnerDialog", "$ionicModal", "$q", "$cordovaBarcodeScanner", "$timeout", "$ionicPopup", function($scope, $state, User, parent, $rootScope, $templateCache, loading, $modal, $q, Hogan, $sanitize, _) {
  /**
   * @param {string} next_callback
   * @return {undefined}
   */
  function onDeviceReady(next_callback) {
    if (window.cordova && window.cordova.plugins) {
      $rootScope.showAlert("", null, next_callback, "确定");
    } else {
      _.alert({
        template : "<div class='tc'>" + next_callback + "</div>",
        okText : "确定"
      });
    }
  }
  /**
   * @return {?}
   */
  function fetch() {
    var imageDfd = $q.defer();
    var request1 = User.httpCacheGet.get(User.httpCacheGet.ac.LogisticsCompany);
    return $q.all([request1]).then(function(image) {
      imageDfd.resolve(image);
    }, function() {
      imageDfd.reject();
    }), imageDfd.promise;
  }
  /** @type {boolean} */
  $scope.isLoading = true;
  $scope.queryCondition = {
    page : 1
  };
  /**
   * @return {?}
   */
  var Step = function() {
    return User.postEncode("/admin/inner/delivery/deliveryCompanyListJSON.ac", $scope.queryCondition);
  };
  /**
   * @return {undefined}
   */
  $scope.getList = function() {
    loading.show(true);
    Step().success(function(data) {
      $scope.items = data.rows;
      /** @type {boolean} */
      $scope.loadMoreBtn = data.page < data.total;
    }).finally(function() {
      parent.scrollTop("deliveryListCtrlScroll");
      loading.hide();
      /** @type {boolean} */
      $scope.isLoading = false;
    });
  };
  /**
   * @return {undefined}
   */
  $scope.getMore = function() {
    $scope.queryCondition.page++;
    loading.show(true);
    Step().success(function(options) {
      $scope.items = $scope.items.concat(options.rows);
      /** @type {boolean} */
      $scope.loadMoreBtn = options.page < options.total;
    }).finally(function() {
      parent.resize("deliveryListCtrlScroll");
      loading.hide();
    });
  };
  $modal.fromTemplateUrl("html/PLogisticsManage/logisticsCompanySelectModal.html", function($location) {
    /** @type {number} */
    $scope.logisticsCompanySelectModal = $location;
  }, {
    scope : $scope,
    animation : "slide-in-up"
  });
  /**
   * @return {?}
   */
  $scope.openQueryTraces = function() {
    return 0 == $scope.getAppAccResource(3) ? ($scope.getAppAuthority(3), false) : void($scope.logisticsTracesModal ? $scope.logisticsTracesModal.isShown() || $scope.logisticsTracesModal.show() : $modal.fromTemplateUrl("html/PLogisticsManage/logisticsTracesModal.html", function($location) {
      $scope.logisticsTracesModal = $location;
      $scope.logisticsTracesModal.show();
    }, {
      scope : $scope,
      animation : "slide-in-up"
    }));
  };
  /**
   * @param {?} dataAndEvents
   * @return {undefined}
   */
  $scope.selectLogisticsCom = function(dataAndEvents) {
    $scope.queryCondition.expCode = $scope.queryCondition.expCode == dataAndEvents.kdnCode ? null : dataAndEvents.kdnCode;
    $scope.logisticsCompanySelectModal.hide();
  };
  /**
   * @return {undefined}
   */
  $scope.scanCodeForLogistics = function() {
    Hogan.scan().then(function(result) {
      if (!result.cancelled) {
        $sanitize(function() {
          $scope.queryCondition.expNo = result.text;
        });
      }
    }, function(err) {
      console.error("Scanning failed: " + err);
      $rootScope.toastShow("二维码扫描失败！");
    });
  };
  /**
   * @return {?}
   */
  $scope.queryLogisticsTraces = function() {
    return $scope.queryCondition.expCode ? $scope.queryCondition.expNo ? (loading.show(), void User.postEncode("/admin/inner/delivery/orderTracesByJson.ac", {
      expCode : $scope.queryCondition.expCode,
      expNo : $scope.queryCondition.expNo
    }).success(function(data) {
      $scope.traceObject = data.object;
      $scope.content = data.content;
    }).finally(function() {
      loading.hide();
    })) : (onDeviceReady("请输入运单号"), false) : (onDeviceReady("请选择快递公司"), false);
  };
  $scope.$on("$destroy", function() {
    $scope.logisticsCompanySelectModal.remove();
    if ($scope.logisticsTracesModal) {
      $scope.logisticsTracesModal.remove();
    }
  });
  $scope.$on("$ionicView.beforeEnter", function() {
    if (1 == $templateCache.get("refreshDeliveryCompanyList")) {
      $scope.getList();
      $templateCache.put("refreshDeliveryCompanyList", false);
    }
  });
  /**
   * @param {string} term
   * @return {undefined}
   */
  $scope.goDetail = function(term) {
    $state.go("eventmenu.deliveryCompanyEdit", {
      id : term
    });
  };
  /**
   * @return {undefined}
   */
  $scope.goPrintLogistics = function() {
    $state.go("eventmenu.printLogisticsForClient");
  };
  $scope.$on("$ionicView.loaded", function() {
    fetch().then(function(packs) {
      $scope.logistics = {};
      $scope.logistics.logisticsCompaniese = packs[0].data;
      $scope.getList();
    });
  });
}]).controller("PrintLogisticsForClientCtrl", ["$scope", "$state", "$stateParams", "psisServices", "$ionicPopup", "$window", "lbSpinnerDialog", "OrderType", "Tools", "$q", "$ionicModal", "BluetoothPrintService", "lruPersistCache", "ServerConfig", function(self, $state, deepDataAndEvents, db, ignoreMethodDoesntExist, $window, loading, err, dojo, $q, $modal, textAlt, lruPersistCache, dataAndEvents) {
  /**
   * @return {?}
   */
  function fetch() {
    var imageDfd = $q.defer();
    var request1 = db.httpCacheGet.get("/admin/system/printTemplate/getMobilePrintConfig.ac?templateKey=mobilePrintTemplate." + self.printSetting.typeId);
    var getPromise3 = db.get("/admin/system/printTemplate/getOnePrintTemplateMobile.ac?orderType=" + self.printSetting.typeId);
    return $q.all([request1, getPromise3]).then(function(image) {
      imageDfd.resolve(image);
    }, function() {
      imageDfd.reject();
    }), imageDfd.promise;
  }
  /**
   * @return {?}
   */
  function resolve() {
    var imageDfd = $q.defer();
    var request1 = db.httpCacheGet.get(db.httpCacheGet.ac.AllArea);
    return $q.all([request1]).then(function(image) {
      imageDfd.resolve(image);
    }, function() {
      imageDfd.reject();
    }), imageDfd.promise;
  }
  /**
   * @return {undefined}
   */
  function require() {
    /** @type {string} */
    var playerName = "";
    /** @type {string} */
    var address = "";
    /** @type {string} */
    var requestUrl = "";
    if (self.printSetting.headerText.name) {
      playerName = self.printSetting.headerText.name;
    }
    if (playerName) {
      if (playerName.length > 0) {
        playerName = playerName.replace(/[\r\n]/g, "");
      }
    }
    if (self.printSetting.headerText.address) {
      address = self.printSetting.headerText.address;
    }
    if (address) {
      if (address.length > 0) {
        address = address.replace(/[\r\n]/g, "");
      }
    }
    if (self.printSetting.headerText.phone) {
      requestUrl = self.printSetting.headerText.phone;
    }
    if (requestUrl) {
      if (requestUrl.length > 0) {
        requestUrl = requestUrl.replace(/[\r\n]/g, "");
      }
    }
    /** @type {string} */
    var qs = "";
    /** @type {string} */
    var ins = "";
    /** @type {string} */
    var desc = "";
    qs = self.client.clientName ? self.client.clientName : "";
    if (qs) {
      if (qs.length > 0) {
        qs = qs.replace(/[\r\n]/g, "");
      }
    }
    desc = self.client.cellphone ? self.client.cellphone : "";
    if (desc) {
      if (desc.length > 0) {
        desc = desc.replace(/[\r\n]/g, "");
      }
    }
    ins = self.client.deliveryAddress;
    if (ins) {
      if (ins.length > 0) {
        ins = ins.replace(/[\r\n]/g, "");
      }
    }
    var failureMessage = self.client.remark ? self.client.remark : "";
    receiverPhone = {
      printType : self.printSetting.printType,
      senderName : playerName,
      senderPhone : requestUrl,
      senderAddress : address,
      receiverName : qs,
      receiverPhone : desc,
      receiverAddress : ins,
      remark : failureMessage,
      isPrintRemark : self.checkColumns && self.checkColumns.indexOf("remark") > -1,
      isPrintDate : self.checkColumns && self.checkColumns.indexOf("date") > -1,
      footerText : self.printSetting.footerText
    };
  }
  if (self.printSetting = {}, self.printSetting.typeId = 31, self.titleName = err.typeName[self.printSetting.typeId], self.printSetting.printType = "ZTO", self.printSetting.printTypesOptions = [{
    value : "ZTO",
    title : "中通"
  }, {
    value : "YTO",
    title : "圆通"
  }, {
    value : "STO",
    title : "申通"
  }, {
    value : "BEST",
    title : "百世汇通"
  }, {
    value : "YUNDA",
    title : "韵达"
  }, {
    value : "SF",
    title : "顺丰"
  }, {
    value : "EMS",
    title : "EMS"
  }, {
    value : "DIY",
    title : "自定义"
  }], dataAndEvents.commonConfig && (dataAndEvents.commonConfig.expressModel && dataAndEvents.commonConfig.expressModel.length > 0)) {
    var codeSegments = dataAndEvents.commonConfig.expressModel;
    /** @type {Array} */
    self.printSetting.printTypesOptions = [];
    /** @type {number} */
    var i = 0;
    for (;i < codeSegments.length;i++) {
      self.printSetting.printTypesOptions.push("Default" != codeSegments[i].key ? {
        value : codeSegments[i].key,
        title : codeSegments[i].name
      } : {
        value : "DIY",
        title : "自定义"
      });
    }
  }
  /** @type {string} */
  self.printSetting.printSize = "ep-basic";
  /** @type {Array} */
  self.printSetting.printTimesOptions = [{
    value : 1,
    title : "1次"
  }, {
    value : 2,
    title : "2次"
  }, {
    value : 3,
    title : "3次"
  }, {
    value : 4,
    title : "4次"
  }, {
    value : 5,
    title : "5次"
  }];
  self.clientPrintOjb = {
    client : {}
  };
  self.client = {
    clientName : "",
    deliveryAddress : "",
    cellphone : ""
  };
  var footerText = {
    senderNameX : 3,
    senderNameY : 5,
    senderNameW : 25,
    senderAddressX : 3,
    senderAddressY : 7,
    senderAddressW : 35,
    senderPhoneX : 3,
    senderPhoneY : 12,
    senderPhoneW : 12,
    receiverNameX : 53,
    receiverNameY : 5,
    receiverNameW : 25,
    receiverAddressX : 53,
    receiverAddressY : 7,
    receiverAddressW : 35,
    receiverPhoneX : 53,
    receiverPhoneY : 12,
    receiverPhoneW : 12,
    remarkX : 2,
    remarkY : 14,
    remarkW : 18
  };
  $modal.fromTemplateUrl("html/PLogisticsManage/printLogisticsForClient.html", function(theTitle) {
    self.printLogisticsForClientModal = theTitle;
  }, {
    scope : self,
    animation : "slide-in-up"
  });
  $modal.fromTemplateUrl("html/PRetailAndSellBill/selectClient.html", function(theTitle) {
    self.clientModal = theTitle;
  }, {
    scope : self,
    animation : "slide-in-up",
    focusFirstInput : true
  });
  /**
   * @return {undefined}
   */
  self.clientModalOpen = function() {
    self.clientModal.show().then(function() {
      dojo.keyboardShow();
    });
  };
  self.$on("$destroy", function() {
    self.printLogisticsForClientModal.remove();
    self.clientModal.remove();
  });
  /** @type {number} */
  self.printSetting.printTimes = 1;
  /** @type {Array} */
  self.columnList = [];
  /** @type {Array} */
  self.checkColumns = [];
  loading.show();
  self.$on("$ionicView.loaded", function() {
    fetch().then(function(packs) {
      if (self.columnList = eval(packs[0].data.object), packs[1].data.object) {
        self.printSetting.id = packs[1].data.object.id;
        self.printSetting.printType = $window.localStorage.printType ? $window.localStorage.printType : packs[1].data.object.printType ? packs[1].data.object.printType : "ZTO";
        try {
          /** @type {*} */
          self.printSetting.headerText = packs[1].data.object.headerText ? JSON.parse(packs[1].data.object.headerText) : {};
        } catch (e) {
          self.printSetting.headerText = {};
        }
        try {
          /** @type {*} */
          self.printSetting.footerText = packs[1].data.object.footerText ? JSON.parse(packs[1].data.object.footerText) : footerText;
        } catch (e) {
          self.printSetting.footerText = footerText;
        }
        self.checkColumns = null != packs[1].data.object.selectColumnNames && "" != packs[1].data.object.selectColumnNames ? packs[1].data.object.selectColumnNames.split(",") : [];
        self.printSetting.optimisticLockVersion = packs[1].data.object.optimisticLockVersion;
        self.printSetting.printTimes = null == packs[1].data.object.printTimes ? 1 : packs[1].data.object.printTimes;
        $window.localStorage["PrintTimes" + self.printSetting.typeId] = self.printSetting.printTimes;
      } else {
        if (self.printSetting.headerText = {}, self.printSetting.footerText = footerText, null != self.columnList) {
          /** @type {number} */
          var a = 0;
          for (;a < self.columnList.length;a++) {
            if ("discount" != self.columnList[a].name) {
              if ("discountAmount" != self.columnList[a].name) {
                self.checkColumns.push(self.columnList[a].name);
              }
            }
          }
        }
      }
      loading.hide();
    }, function() {
      dojo.toastShow("获取数据过程中出错！");
      loading.hide();
    });
  });
  /**
   * @param {string} key
   * @return {undefined}
   */
  self.selectColumn = function(key) {
    var camelKey = self.checkColumns.indexOf(key);
    if (camelKey > -1) {
      self.checkColumns.splice(camelKey, 1);
    } else {
      self.checkColumns.push(key);
    }
  };
  /** @type {Array} */
  var key = [];
  var receiverPhone = {};
  /**
   * @return {undefined}
   */
  self.print = function() {
    require();
    lruPersistCache.put("bluePrintType", 31);
    $state.go("eventmenu.bluetoothPrintList", {
      isClientExpress : true,
      printTimes : self.printSetting.printTimes,
      printObject : receiverPhone
    });
  };
  /**
   * @param {string} type
   * @return {undefined}
   */
  self.getPrintData = function(type) {
    loading.show();
    resolve().then(function(packs) {
      key = packs[0].data;
      var value = dojo.getObjectList(key, "pid", 0);
      /** @type {string} */
      var str = "";
      var that = {};
      db.post("/admin/inner/client/clientGet.ac?id=" + type).success(function(message) {
        var remark = self.client.remark;
        if (self.client = message.objClient, self.client.provinceId && (that.province = dojo.fnCheckGtoreQty(value, "id", self.client.provinceId), str += that.province && that.province.areaName ? that.province.areaName : "", self.client.cityId)) {
          var node = dojo.getObjectList(key, "pid", that.province.id);
          if (that.city = dojo.fnCheckGtoreQty(node, "id", self.client.cityId), str += that.city && that.city.areaName ? that.city.areaName : "", self.client.countyId) {
            var camelKey = dojo.getObjectList(key, "pid", that.city.id);
            that.country = dojo.fnCheckGtoreQty(camelKey, "id", self.client.countyId);
            str += that.country && that.country.areaName ? that.country.areaName : "";
          }
        }
        str += self.client.address ? self.client.address : "";
        self.client.deliveryAddress = str;
        self.client.remark = remark;
      }).finally(function() {
        loading.hide();
      });
    }, function() {
      dojo.toastShow("获取数据过程中异常！");
      loading.hide();
    });
  };
  self.$on("$ionicView.beforeEnter", function() {
    if (lruPersistCache.get("needToAddClientFlag") === true) {
      lruPersistCache.put("needToAddClientFlag", false);
      lruPersistCache.put("addClientFlag", false);
      var params = lruPersistCache.get("newClientObj");
      if (params && params.id) {
        var onComplete = {
          val : params.id,
          text : params.clientName
        };
        self.clientPrintOjb.selectClient(onComplete);
        lruPersistCache.put("newClientObj", null);
      }
    }
  });
  self.$on("$ionicView.beforeLeave", function() {
    $window.localStorage.printType = self.printSetting.printType;
  });
}]).controller("DeliveryCompanyEditCtrl", ["$scope", "$state", "psisServices", "lbScrollDelegate", "Tools", "$stateParams", "lbSpinnerDialog", "$ionicModal", "$ionicPopup", "lruPersistCache", "$q", "$ionicPopover", function(self, dataAndEvents, doc, deepDataAndEvents, assert, ignores, loading, $modal, _, $templateCache, $q, FB) {
  /**
   * @return {?}
   */
  function fetch() {
    var imageDfd = $q.defer();
    var request1 = doc.httpCacheGet.get(doc.httpCacheGet.ac.LogisticsCompany);
    var getPromise3 = doc.httpCacheGet.get(doc.httpCacheGet.ac.AllArea);
    return $q.all([request1, getPromise3]).then(function(image) {
      imageDfd.resolve(image);
    }, function() {
      imageDfd.reject();
    }), imageDfd.promise;
  }
  self.isUserAccAvailable = self.GetOperatorEventLimit("2208");
  self.deliveryViewTitle = ignores.id ? self.NameConstant.DELIVERYEDIT : self.NameConstant.DELIVERYADD;
  /** @type {number} */
  self.state = 0;
  self.deliveryItem = {
    deliveryCompany : {
      siteUrl : ""
    },
    netPoints : []
  };
  self.deliveryCondition = {
    showDelete : false
  };
  self.selectedNetPoint = {};
  /** @type {string} */
  self.selectedType = "";
  self.netPointTemp = {};
  $modal.fromTemplateUrl("netPoint.html", function(theTitle) {
    /** @type {number} */
    self.netPointModal = theTitle;
  }, {
    scope : self,
    animation : "slide-in-up"
  });
  $modal.fromTemplateUrl("provinceSelect.html", function(theTitle) {
    self.provinceSelectModal = theTitle;
  }, {
    scope : self,
    animation : "slide-in-up"
  });
  $modal.fromTemplateUrl("citySelect.html", function(theTitle) {
    self.citySelectModal = theTitle;
  }, {
    scope : self,
    animation : "slide-in-up"
  });
  $modal.fromTemplateUrl("countrySelect.html", function(theTitle) {
    self.countrySelectModal = theTitle;
  }, {
    scope : self,
    animation : "slide-in-up"
  });
  /**
   * @return {undefined}
   */
  self.netPointModalOpen = function() {
    self.netPointModal.show();
    /** @type {boolean} */
    self.focusInput = true;
  };
  /**
   * @param {string} obj
   * @return {undefined}
   */
  self.netPointModalClose = function(obj) {
    if ("upd" === self.selectedType) {
      if ("close" === obj) {
        self.selectedNetPoint.name = self.netPointTemp.name;
        self.selectedNetPoint.address = self.netPointTemp.address;
        self.selectedNetPoint.phone = self.netPointTemp.phone;
      }
    }
    self.netPointModal.hide();
    /** @type {boolean} */
    self.focusInput = false;
  };
  $modal.fromTemplateUrl("html/PLogisticsManage/logisticsCompanySelectModal.html", function(theTitle) {
    /** @type {number} */
    self.logisticsCompanySelectModal = theTitle;
  }, {
    scope : self,
    animation : "slide-in-up"
  });
  FB.fromTemplateUrl("payTypes.html", {
    scope : self
  }).then(function(theTitle) {
    self.payTypesPopover = theTitle;
  });
  /**
   * @param {?} ignores
   * @return {undefined}
   */
  self.selectLogisticsCom = function(ignores) {
    if (self.deliveryItem.deliveryCompany.logisticsCompanyId == ignores.id) {
      /** @type {null} */
      self.deliveryItem.deliveryCompany.logisticsCompanyId = null;
    } else {
      self.deliveryItem.deliveryCompany.logisticsCompanyId = ignores.id;
      self.logistics.selectedCompany = ignores;
    }
    self.logisticsCompanySelectModal.hide();
  };
  /**
   * @param {Object} val
   * @return {undefined}
   */
  self.modifyNetPoint = function(val) {
    if (val) {
      /** @type {Object} */
      self.selectedNetPoint = val;
      self.netPointTemp = assert.getPropertyObj(val, ["address", "name", "phone"]);
      /** @type {string} */
      self.selectedType = "upd";
    } else {
      self.selectedNetPoint = {
        name : "",
        phone : "",
        address : ""
      };
      /** @type {string} */
      self.selectedType = "add";
    }
    self.netPointModalOpen();
  };
  /**
   * @return {undefined}
   */
  self.saveNetPointConfirm = function() {
    if (self.selectedNetPoint.name && (null !== self.selectedNetPoint.name && "" !== self.selectedNetPoint.name)) {
      if (void 0 === self.selectedNetPoint.phone) {
        assert.toastShow("电话输入值必须是数字或-！", "short", "center");
        e.preventDefault();
      } else {
        if ("add" == self.selectedType) {
          self.deliveryItem.netPoints.push(self.selectedNetPoint);
        }
        self.netPointModalClose("save");
      }
    } else {
      assert.toastShow("请填写名称！", "short", "center");
      e.preventDefault();
    }
  };
  /**
   * @param {Element} elem
   * @return {undefined}
   */
  self.deleteNetPoint = function(elem) {
    /** @type {number} */
    var i = 0;
    for (;i < self.deliveryItem.netPoints.length;i++) {
      if (elem.id == self.deliveryItem.netPoints[i].id) {
        self.deliveryItem.netPoints.splice(i, 1);
        break;
      }
    }
    if (assert.isEmpty(self.deliveryItem.netPoints)) {
      /** @type {boolean} */
      self.deliveryCondition.showDelete = false;
    }
  };
  self.$on("$destroy", function() {
    self.netPointModal.remove();
    self.logisticsCompanySelectModal.remove();
    self.payTypesPopover.remove();
    self.provinceSelectModal.remove();
    self.citySelectModal.remove();
    self.countrySelectModal.remove();
  });
  /**
   * @return {?}
   */
  self.isNetPointsNull = function() {
    return assert.isEmpty(self.deliveryItem.netPoints) ? true : false;
  };
  /**
   * @return {undefined}
   */
  self.deleteDeliveryCompany = function() {
    var promise = _.confirm({
      template : "<div class='tc'>您确认要删除该物流？</div>",
      cancelText : "取消",
      okText : "确认"
    });
    promise.then(function(dataAndEvents) {
      if (dataAndEvents) {
        loading.show(true);
        doc.post("/admin/inner/delivery/deliveryCompanyDelete.ac?id=" + self.deliveryItem.deliveryCompany.id).success(function(r) {
          if (1 == r.statusCode) {
            _.alert({
              template : "<div class='tc'>删除成功</div>",
              okText : "确定"
            }).then(function() {
              self.goBack();
              $templateCache.put("refreshDeliveryCompanyList", true);
              doc.httpCacheGet.remove(doc.httpCacheGet.ac.ALLDELIVERY);
            });
          } else {
            _.alert({
              template : "<div class='tc'>删除失败，不能删除已被使用的物流！</div>",
              okText : "确定"
            });
          }
        }).finally(function() {
          loading.hide();
        });
      }
    });
  };
  /** @type {Array} */
  self.payTypes = [{
    text : "现付",
    val : 1
  }, {
    text : "到付",
    val : 2
  }, {
    text : "月结",
    val : 3
  }, {
    text : "第三方支付",
    val : 4
  }];
  /**
   * @return {?}
   */
  self.saveDeliveryCompany = function() {
    return self.deliveryItem.deliveryCompany.name ? void 0 === self.deliveryItem.deliveryCompany.siteUrl ? (assert.toastShow("请输入正确的网址，如http://www.xinbafar.com", "short", "center"), false) : (self.deliveryItem.deliveryCompany.payTypeObject && self.deliveryItem.deliveryCompany.payTypeObject.val > 0 ? self.deliveryItem.deliveryCompany.payType = self.deliveryItem.deliveryCompany.payTypeObject.val :
    delete self.deliveryItem.deliveryCompany.payType, self.senderInfo.province && self.senderInfo.province.id > 0 ? self.deliveryItem.deliveryCompany.senderProvincesId = self.senderInfo.province.id : delete self.deliveryItem.deliveryCompany.senderProvincesId, self.senderInfo.city && self.senderInfo.city.id > 0 ? self.deliveryItem.deliveryCompany.senderCityId = self.senderInfo.city.id : delete self.deliveryItem.deliveryCompany.senderCityId,
    self.senderInfo.country && self.senderInfo.country.id > 0 ? self.deliveryItem.deliveryCompany.senderCountyId = self.senderInfo.country.id : delete self.deliveryItem.deliveryCompany.senderCountyId, loading.show(), void doc.post("/admin/inner/delivery/saveDeliveryCompany.ac", self.deliveryItem).success(function(res) {
      if (1 == res.statusCode) {
        _.alert({
          template : "<div class='tc'>保存成功</div>",
          okText : "确定"
        }).then(function() {
          assert.union(self.deliveryItem, res.object);
          /** @type {number} */
          self.state = 1;
          /** @type {string} */
          self.selectedType = "";
          /** @type {boolean} */
          self.deliveryCondition.showDelete = false;
          self.viewTitle = self.NameConstant.DELIVERYEDIT;
          $templateCache.put("refreshDeliveryCompanyList", true);
          doc.httpCacheGet.remove(doc.httpCacheGet.ac.ALLDELIVERY);
        });
      } else {
        _.alert({
          template : "<div class='tc'>保存失败</div>",
          okText : "确定"
        });
      }
    }).finally(function() {
      loading.hide();
    })) : (assert.toastShow("需要填写名称！", "short", "center"), false);
  };
  /**
   * @return {undefined}
   */
  self.changeToAdd = function() {
    /** @type {number} */
    self.state = 0;
    self.deliveryViewTitle = self.NameConstant.DELIVERYADD;
    self.deliveryItem.deliveryCompany = {
      siteUrl : ""
    };
    /** @type {Array} */
    self.deliveryItem.netPoints = [];
    /** @type {boolean} */
    self.deliveryCondition.showDelete = false;
  };
  self.$on("$ionicView.loaded", function() {
    loading.show(true);
    fetch().then(function(packs) {
      self.logistics = {};
      self.logistics.logisticsCompaniese = packs[0].data;
      /** @type {Array} */
      var key = [];
      self.senderInfo = {};
      key = packs[1].data;
      self.provinceItems = assert.getObjectList(key, "pid", 0);
      /** @type {Array} */
      self.cityItems = [];
      /** @type {Array} */
      self.countryItems = [];
      self.$watch("senderInfo.province", function() {
        if (assert.isEmpty(self.senderInfo.province)) {
          /** @type {Array} */
          self.cityItems = [];
          /** @type {Array} */
          self.countryItems = [];
        } else {
          self.cityItems = assert.getObjectList(key, "pid", self.senderInfo.province.id);
          /** @type {Array} */
          self.countryItems = [];
        }
      });
      self.$watch("senderInfo.city", function() {
        self.countryItems = assert.isEmpty(self.senderInfo.city) ? [] : assert.getObjectList(key, "pid", self.senderInfo.city.id);
      });
      if (ignores.id) {
        /** @type {number} */
        self.state = 1;
        doc.post("/admin/inner/delivery/deliveryCompanyGet.ac?id=" + ignores.id).success(function(dataAndEvents) {
          self.deliveryItem.deliveryCompany = dataAndEvents.deliveryCompany;
          self.deliveryItem.netPoints = dataAndEvents.netPoints;
          /** @type {number} */
          var i = 0;
          for (;i < self.logistics.logisticsCompaniese.length;i++) {
            if (self.logistics.logisticsCompaniese[i].id == self.deliveryItem.deliveryCompany.logisticsCompanyId) {
              self.logistics.selectedCompany = self.logistics.logisticsCompaniese[i];
            }
          }
          if (self.deliveryItem.deliveryCompany.payTypeObject = assert.fnCheckGtoreQty(self.payTypes, "val", self.deliveryItem.deliveryCompany.payType), self.deliveryItem.deliveryCompany && (self.deliveryItem.deliveryCompany.senderProvincesId && (self.senderInfo.province = assert.fnCheckGtoreQty(self.provinceItems, "id", self.deliveryItem.deliveryCompany.senderProvincesId), self.deliveryItem.deliveryCompany.senderCityId))) {
            var camelKey = assert.getObjectList(key, "pid", self.senderInfo.province.id);
            if (self.senderInfo.city = assert.fnCheckGtoreQty(camelKey, "id", self.deliveryItem.deliveryCompany.senderCityId), self.deliveryItem.deliveryCompany.senderCountyId) {
              var node = assert.getObjectList(key, "pid", self.senderInfo.city.id);
              self.senderInfo.country = assert.fnCheckGtoreQty(node, "id", self.deliveryItem.deliveryCompany.senderCountyId);
            }
          }
        }).finally(function() {
          loading.hide();
        });
      } else {
        loading.hide();
      }
    });
  });
}]).controller("EorderListCtrl", ["$scope", "$state", "psisServices", "$ionicModal", "lbScrollDelegate", "Tools", "lruPersistCache", "$cordovaDatePicker", "lbSpinnerDialog", "BTScanerService", "$ionicPopover", "$timeout", "BluetoothPrintService", function(self, ret, assert, dataAndEvents, parent, $, $templateCache, deepDataAndEvents, loading, $document, ignoreMethodDoesntExist, $sanitize, $animate) {
  /** @type {string} */
  self.viewTitle = "打印快递面单";
  self.listQueryClient = {};
  /** @type {number} */
  self._itemType = 1;
  /** @type {boolean} */
  self.isLoading = true;
  self.queryCondition = {
    page : 1,
    itemType : self._itemType,
    state : 1
  };
  self.salerCondition = {};
  /**
   * @return {?}
   */
  var Step = function() {
    /** @type {string} */
    var suiteView = "/admin/inner/sale/orderOnlineListJSON.ac";
    return assert.postEncode(suiteView, self.queryCondition);
  };
  /**
   * @return {undefined}
   */
  self.getList = function() {
    /** @type {number} */
    self.queryCondition.page = 1;
    if (self.listQueryClient.isShowPrintCounts) {
      /** @type {number} */
      self.queryCondition.isShowPrintCounts = 1;
    } else {
      delete self.queryCondition.isShowPrintCounts;
    }
    loading.show();
    Step().success(function(data) {
      self.items = data.rows;
      /** @type {boolean} */
      self.loadMoreBtn = data.page < data.total;
    }).finally(function() {
      /** @type {boolean} */
      self.isLoading = false;
      loading.hide();
      parent.scrollTop("saleListCtrlScroll");
    });
  };
  /**
   * @return {undefined}
   */
  self.getMore = function() {
    self.queryCondition.page++;
    Step().success(function(options) {
      self.items = self.items.concat(options.rows);
      /** @type {boolean} */
      self.loadMoreBtn = options.page < options.total;
      self.$broadcast("scroll.infiniteScrollComplete");
    }).finally(function() {
      parent.resize("saleListCtrlScroll");
    });
  };
  /**
   * @param {?} dataAndEvents
   * @param {(number|string)} deepDataAndEvents
   * @return {undefined}
   */
  self.goSale = function(dataAndEvents, deepDataAndEvents) {
    var rreturn;
    if (1 === deepDataAndEvents) {
      switch(self._itemType) {
        case 1:
          /** @type {string} */
          rreturn = "eventmenu.saleEdit";
          break;
        case 2:
          /** @type {string} */
          rreturn = "eventmenu.saleReturnEdit";
      }
    } else {
      switch(self._itemType) {
        case 1:
          /** @type {string} */
          rreturn = "eventmenu.saleDetail";
          break;
        case 2:
          /** @type {string} */
          rreturn = "eventmenu.saleReturnDetail";
      }
    }
    ret.go(rreturn, {
      ordersSn : dataAndEvents
    });
  };
  /**
   * @param {?} argument
   * @return {?}
   */
  self.getTotalAmount = function(argument) {
    var initial = argument.trueTotalAmount < 0 ? -argument.trueTotalAmount : argument.trueTotalAmount;
    return argument.otherCost && (initial = $.accAdd(initial, argument.otherCost)), argument.wipeZero && (initial = $.accSub(initial, argument.wipeZero)), initial;
  };
  /** @type {Array} */
  self.selectedItems = [];
  self.obj = {};
  /** @type {boolean} */
  self.obj.isSelectedOrders = true;
  /**
   * @param {string} item
   * @param {?} event
   * @return {undefined}
   */
  self.selectOrders = function(item, event) {
    if (event) {
      event.stopPropagation();
    }
    var ix = self.selectedItems.indexOf(item);
    if (ix > -1) {
      /** @type {string} */
      item.quantity = "";
      self.selectedItems.splice(ix, 1);
    } else {
      if (item.deliverySn && item.deliverySn.length > 0) {
        if (item.quantity > 0) {
          self.selectedItems.push(item);
        } else {
          /** @type {number} */
          item.quantity = 1;
          self.selectedItems.push(item);
        }
      } else {
        $.toastShow("该单据没有成功订阅电子面单，不可选择");
      }
    }
  };
  /**
   * @return {undefined}
   */
  self.selectOption = function() {
    /** @type {boolean} */
    self.obj.isSelectedOrders = !self.obj.isSelectedOrders;
    /** @type {Array} */
    self.selectedItems = [];
  };
  /**
   * @return {undefined}
   */
  self.printEorderArray = function() {
    if (self.selectedItems && self.selectedItems.length > 0) {
      /** @type {Array} */
      var root = [];
      /** @type {number} */
      var i = 0;
      for (;i < self.selectedItems.length;i++) {
        root.push(self.selectedItems[i].deliverySn);
      }
      $animate.bluetooth(root, $animate.orderType.eorder);
    } else {
      $.toastShow("请选择单据进行打印快递单");
    }
  };
  self.$on("$ionicView.beforeEnter", function() {
    if ($templateCache.get("saleListRefresh")) {
      if ($templateCache.get("saleListRefresh") === true) {
        self.getList();
        $templateCache.put("saleListRefresh", false);
      }
    }
    $document.getScanerCode(function(fmt) {
      console.log(fmt);
    }, self.bluethoothScaner);
    if (self.platformIsAndroid) {
      $sanitize(function() {
        if (window.plugins) {
          if (window.plugins.bluetoothPrinter) {
            window.plugins.bluetoothPrinter.close(angular.noop, angular.noop);
          }
        }
      }, 2E3);
    }
  });
  self.$on("$ionicView.loaded", function() {
    self.getList();
  });
}]).controller("LogisticsOrderListCtrl", ["$scope", "$state", "psisServices", "$ionicModal", "lbScrollDelegate", "Tools", "lruPersistCache", "$cordovaDatePicker", "BTScanerService", "lbSpinnerDialog", "$ionicPopover", "$timeout", "BluetoothPrintService", "$window", function(self, ret, _, $modal, parent, dataAndEvents, $templateCache, $scope, $document, loading, FB, $sanitize, $animate, $window) {
  /** @type {string} */
  self.selectTiltle = "全选";
  /** @type {Array} */
  self.selectedItems = [];
  var character;
  var chr;
  if (self.commonConfig) {
    var n = self.commonConfig.orderListDays;
    if (n) {
      character = (new Date).setDate((new Date).getDate() - n);
      /** @type {number} */
      chr = (new Date).getTime();
    }
  }
  self.listQueryClient = {};
  self.listQueryClient.createTimeBegin = character ? character : "";
  /** @type {(number|string)} */
  self.listQueryClient.createTimeEnd = chr ? chr : "";
  /** @type {boolean} */
  self.isLoading = true;
  self.queryCondition = {
    page : 1,
    itemType : 1,
    state : 12
  };
  self.salerCondition = {};
  /**
   * @return {?}
   */
  var Step = function() {
    /** @type {string} */
    var reversed = "";
    switch(self.queryCondition.itemType) {
      case 1:
        /** @type {string} */
        reversed = "/admin/inner/sale/wholesaleOrdersListJSON.ac";
        break;
      case 2:
        /** @type {string} */
        reversed = "/admin/inner/sale/rejectWholesaleOrdersListJSON.ac";
    }
    return _.postEncode(reversed, self.queryCondition);
  };
  /**
   * @return {undefined}
   */
  self.getList = function() {
    /** @type {number} */
    self.queryCondition.page = 1;
    if (self.listQueryClient.createTimeBegin) {
      self.queryCondition.createTimeBegin = dataAndEvents.getDayBeginStr(self.listQueryClient.createTimeBegin);
    } else {
      delete self.queryCondition.createTimeBegin;
    }
    if (self.listQueryClient.createTimeEnd) {
      self.queryCondition.createTimeEnd = dataAndEvents.getOffsetDayBeginStr(self.listQueryClient.createTimeEnd, 1);
    } else {
      delete self.queryCondition.createTimeEnd;
    }
    if (self.salerCondition.saler && self.salerCondition.saler.val) {
      self.queryCondition.salerId = self.salerCondition.saler.val;
    } else {
      delete self.queryCondition.salerId;
    }
    if (0 == self.queryCondition.state) {
      delete self.queryCondition.state;
    }
    if (self.queryCondition.clientId) {
      delete self.queryCondition.clientIsNull;
    }
    loading.show();
    Step().success(function(data) {
      self.items = data.rows;
      /** @type {boolean} */
      self.loadMoreBtn = data.page < data.total;
      /** @type {Array} */
      self.selectedItems = [];
      /** @type {string} */
      self.selectTiltle = "全选";
    }).finally(function() {
      /** @type {boolean} */
      self.isLoading = false;
      loading.hide();
      parent.scrollTop("logisticsListCtrlScroll");
    });
  };
  /**
   * @return {undefined}
   */
  self.getMore = function() {
    self.queryCondition.page++;
    Step().success(function(options) {
      self.items = self.items.concat(options.rows);
      /** @type {boolean} */
      self.loadMoreBtn = options.page < options.total;
      self.$broadcast("scroll.infiniteScrollComplete");
    }).finally(function() {
      parent.resize("logisticsListCtrlScroll");
    });
  };
  /**
   * @return {undefined}
   */
  self.setCreateTimeBegin = function() {
    $scope.show({
      date : self.listQueryClient.createTimeBegin ? new Date(self.listQueryClient.createTimeBegin) : new Date,
      mode : "date",
      minDate : "",
      maxDate : "",
      doneButtonLabel : "确定",
      cancelButtonLabel : "取消"
    }).then(function(date1) {
      if (!isNaN(date1.getTime())) {
        self.listQueryClient.createTimeBegin = date1.getTime();
      }
    });
  };
  /**
   * @return {undefined}
   */
  self.setCreateTimeEnd = function() {
    $scope.show({
      date : self.listQueryClient.createTimeEnd ? new Date(self.listQueryClient.createTimeEnd) : new Date,
      mode : "date",
      minDate : "",
      maxDate : "",
      doneButtonLabel : "确定",
      cancelButtonLabel : "取消"
    }).then(function(date1) {
      if (!isNaN(date1.getTime())) {
        self.listQueryClient.createTimeEnd = date1.getTime();
      }
    });
  };
  /**
   * @return {undefined}
   */
  self.clearQueryCondition = function() {
    /** @type {null} */
    self.listQueryClient.createTimeBegin = null;
    /** @type {null} */
    self.listQueryClient.createTimeEnd = null;
    /** @type {string} */
    self.listQueryClient.text = "";
    delete self.queryCondition.clientId;
    delete self.queryCondition.ordersSn;
    delete self.queryCondition.clientIsNull;
    delete self.queryCondition.salerId;
    /** @type {number} */
    self.queryCondition.itemType = 1;
    self.salerCondition = {};
  };
  /**
   * @param {string} dataAndEvents
   * @param {(number|string)} deepDataAndEvents
   * @param {?} event
   * @return {undefined}
   */
  self.goSale = function(dataAndEvents, deepDataAndEvents, event) {
    if (event) {
      event.stopPropagation();
    }
    var rreturn;
    if (1 === deepDataAndEvents) {
      switch(self.queryCondition.itemType) {
        case 1:
          /** @type {string} */
          rreturn = "eventmenu.saleEdit";
          break;
        case 2:
          /** @type {string} */
          rreturn = "eventmenu.saleReturnEdit";
      }
    } else {
      switch(self.queryCondition.itemType) {
        case 1:
          /** @type {string} */
          rreturn = "eventmenu.saleDetail";
          break;
        case 2:
          /** @type {string} */
          rreturn = "eventmenu.saleReturnDetail";
      }
    }
    ret.go(rreturn, {
      ordersSn : dataAndEvents
    });
  };
  $modal.fromTemplateUrl("saleListQuery.html", function(theTitle) {
    self.saleListQueryModal = theTitle;
  }, {
    scope : self,
    animation : "slide-in-up"
  });
  $modal.fromTemplateUrl("html/PRetailAndSellBill/selectClient.html", function(theTitle) {
    self.clientModal = theTitle;
  }, {
    scope : self,
    animation : "slide-in-up"
  });
  /**
   * @return {undefined}
   */
  self.clientModalOpen = function() {
    self.clientModal.show();
  };
  FB.fromTemplateUrl("salerPopover.html", {
    scope : self
  }).then(function(theTitle) {
    self.salerPopover = theTitle;
  });
  /**
   * @param {boolean} expectedNumberOfNonCommentArgs
   * @return {undefined}
   */
  self.openSalerPopover = function(expectedNumberOfNonCommentArgs) {
    self.salerPopover.show(expectedNumberOfNonCommentArgs);
  };
  /**
   * @return {undefined}
   */
  self.hideSalerPopover = function() {
    self.salerPopover.hide();
  };
  $modal.fromTemplateUrl("html/PRetailAndSellBill/SellBillSelectSaler.html", function(theTitle) {
    self.salerModal = theTitle;
  }, {
    scope : self,
    animation : "slide-in-up",
    focusFirstInput : true
  });
  /**
   * @param {boolean} expectedNumberOfNonCommentArgs
   * @return {undefined}
   */
  self.salerModalOpen = function(expectedNumberOfNonCommentArgs) {
    self.salerModal.show(expectedNumberOfNonCommentArgs).then(function() {
      dataAndEvents.keyboardShow();
    });
  };
  FB.fromTemplateUrl("logisticsOrderType.html", {
    scope : self
  }).then(function(theTitle) {
    /** @type {number} */
    self.logisticsOrderTypePopover = theTitle;
  });
  /**
   * @param {boolean} expectedNumberOfNonCommentArgs
   * @return {undefined}
   */
  self.openLogisticsOrderPopover = function(expectedNumberOfNonCommentArgs) {
    self.logisticsOrderTypePopover.show(expectedNumberOfNonCommentArgs);
  };
  /**
   * @return {undefined}
   */
  self.hideLogisticsOrderPopover = function() {
    self.logisticsOrderTypePopover.hide();
  };
  /**
   * @param {string} item
   * @param {?} event
   * @return {undefined}
   */
  self.selectOrders = function(item, event) {
    if (event) {
      event.stopPropagation();
    }
    var ix = self.selectedItems.indexOf(item);
    if (ix > -1) {
      /** @type {string} */
      item.quantity = "";
      self.selectedItems.splice(ix, 1);
    } else {
      if (item.quantity > 0) {
        self.selectedItems.push(item);
      } else {
        /** @type {number} */
        item.quantity = 1;
        self.selectedItems.push(item);
      }
    }
  };
  /**
   * @return {undefined}
   */
  self.selectAllOrders = function() {
    if (!(self.items.length < 1)) {
      if ("全选" == self.selectTiltle) {
        /** @type {Array} */
        self.selectedItems = [];
        /** @type {number} */
        var i = 0;
        for (;i < self.items.length;i++) {
          self.selectedItems.push(self.items[i]);
        }
        /** @type {string} */
        self.selectTiltle = "取消";
      } else {
        /** @type {string} */
        self.selectTiltle = "全选";
        /** @type {Array} */
        self.selectedItems = [];
      }
    }
  };
  /**
   * @return {undefined}
   */
  self.userDefinedPrint = function() {
    ret.go("eventmenu.printLogisticsForClient");
  };
  /**
   * @return {undefined}
   */
  self.printExpressArray = function() {
    if (self.selectedItems && self.selectedItems.length > 0) {
      /** @type {Array} */
      var root = [];
      /** @type {number} */
      var i = 0;
      for (;i < self.selectedItems.length;i++) {
        root.push(self.selectedItems[i].ordersSn);
      }
      /** @type {number} */
      $window.localStorage["PrintTimes" + $animate.orderType.logisticsOrder] = 1;
      $animate.bluetooth(root, $animate.orderType.logisticsOrder);
    } else {
      dataAndEvents.toastShow("请选择单据进行快递单打印");
    }
  };
  self.$on("$destroy", function() {
    self.saleListQueryModal.remove();
    self.clientModal.remove();
    self.salerModal.remove();
    if (self.salerPopover) {
      self.salerPopover.remove();
    }
    if (self.logisticsOrderTypePopover) {
      self.logisticsOrderTypePopover.remove();
    }
  });
  self.$on("$ionicView.beforeEnter", function() {
    if (1 == $templateCache.get("logisticsListRefresh")) {
      self.getList();
      $templateCache.put("logisticsListRefresh", false);
    }
    $document.getScanerCode(function(fmt) {
      console.log(fmt);
    }, self.bluethoothScaner);
    if (self.platformIsAndroid) {
      $sanitize(function() {
        if (window.plugins) {
          if (window.plugins.bluetoothPrinter) {
            window.plugins.bluetoothPrinter.close(angular.noop, angular.noop);
          }
        }
      }, 2E3);
    }
  });
  self.$on("$ionicView.loaded", function() {
    self.getList();
    _.httpCacheGet.get(_.httpCacheGet.ac.COMPANYUSERBYPARAM).success(function(message) {
      self.allSaler = message.optionList;
    });
  });
}]);
